@@ -19,16 +19,15 @@ def get_probe_runner_host():
     return "https://proberunner.internal.olympus-world.zetaapps.in"
 
 
-def trace():
+def trace(zone):
     os.environ["SKIP_ADAPTER"] = "True"
-    headers = dict()
-    probe_url = get_probe_runner_host() + "/trace/headers"
+    probe_url = get_probe_runner_host() + f"/trace/headers?zone={zone}"
     response = requests.get(url=probe_url, headers=header)
     os.environ["SKIP_ADAPTER"] = "False"
     try:
         headers = response.json()['traceHeaders']
     except:
-        return headers
+        raise TypeError("Could not get headers for the probe.")
     return headers
 
 
@@ -52,18 +51,25 @@ def logged_request(method, url, **kwargs):
         request = None
         response = None
         start_time = int(time.time() * 1000)
+        zone = os.environ.get("ZONE", None)
+        flow_id = os.environ.get("FLOW_ID", None)
 
         try:
             header_dict: dict = kwargs.get('headers', None)
-            zone = os.environ.get("ZONE", None)
-            if header_dict is not None and zone is not None and "nonpcidss" in zone:
-                header_dict.update(trace())
+
+            if zone is None:
+                raise TypeError(
+                    "Current probe has not been associated with a zone. Available zones can be obtained from : https://owcc-ssc.internal.olympus-world.zetaapps.in/zones/names")
+
+            if header_dict is not None and "nonpcidss" in zone:
+                header_dict.update(trace(zone))
             response = original_request_method(method, url, **kwargs)
             request = response.request
         finally:
             end_time = int(time.time() * 1000)
 
-            adapter_data(start_time=start_time, end_time=end_time, request=request, response=response, method=method, url=url)
+            adapter_data(start_time=start_time, end_time=end_time, request=request, response=response, method=method, url=url, flow_id=flow_id,
+                         zone=zone)
         return response
     else:
         return original_request_method(method, url, **kwargs)
@@ -81,11 +87,9 @@ def sanitize_data(data: dict):
     return {k: "******" if is_protected(k) else v for k, v in data.items()}
 
 
-def adapter_data(*, start_time, end_time, request=None, response=None, method=None, url=None):
+def adapter_data(*, start_time, end_time, request=None, response=None, method=None, url=None, flow_id=None, zone=None):
     if request is not None:
         trace_id = request.headers.get("X-Olympus-Traceid", None)
-        flow_id = os.environ.get("FLOW_ID", None)
-        zone = os.environ.get("ZONE", None)
 
         if flow_id is not None and zone is not None:
             del os.environ["FLOW_ID"]
@@ -102,7 +106,6 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
                 "markers": test_name.replace("[" + flow_probe_payload + "]", "").replace("test_", "").replace("tests_", "").lower()
             }
 
-            test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
             flow_probe_name = (test_name.split(":")[0].split(".")[0].replace("tests_", "").replace("test_", "").replace("_", " ").title())
             status_code = response.status_code
             trace_name = request.method
